Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(179)

Unified Diff: vm/ast.cc

Issue 11087070: - Get rid of RawClosure class and use RawInstance for closures. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/runtime/
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/isolate.cc ('k') | vm/code_generator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: vm/ast.cc
===================================================================
--- vm/ast.cc (revision 13564)
+++ vm/ast.cc (working copy)
@@ -286,8 +286,8 @@
const Instance* ClosureNode::EvalConstExpr() const {
if (function().IsImplicitStaticClosureFunction()) {
- // Return a value that represents a closure. Only the type is relevant.
- return &Closure::Handle();
+ // Return a value that represents an instance. Only the type is relevant.
+ return &Instance::Handle();
}
return NULL;
}
« no previous file with comments | « lib/isolate.cc ('k') | vm/code_generator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698